calver: Setuptools extension for CalVer package versions
========================================================

Description
-----------

Setuptools extension for CalVer package versions

License
-------

Upstream Contact
----------------

https://pypi.org/project/calver/

